import { Injectable } from '@angular/core';
import { BehaviorSubject } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class ThemeService {
  private isDarkTheme = new BehaviorSubject<boolean>(false);
  isDarkTheme$ = this.isDarkTheme.asObservable();

  constructor() {
    const storedTheme = this.getStoredTheme();
    this.isDarkTheme.next(storedTheme);
    this.applyTheme(storedTheme);
  }

  private getStoredTheme(): boolean {
    const storedTheme = localStorage.getItem('darkTheme');
    if (storedTheme !== null) {
      return JSON.parse(storedTheme);
    }
    return false; // Default to light theme
  }

  toggleTheme(): void {
    const newTheme = !this.isDarkTheme.value;
    this.isDarkTheme.next(newTheme);
    localStorage.setItem('darkTheme', JSON.stringify(newTheme));
    this.applyTheme(newTheme);
  }

  private applyTheme(isDark: boolean): void {
    if (isDark) {
      document.body.classList.add('dark-theme');
    } else {
      document.body.classList.remove('dark-theme');
    }
  }
} 